TBR renaming party

MultiPart: 4/10
Change-Id: I31058b1146bc22f1f12378a00666beeb82c6f0c9
diff --git a/services/wsprd/account/account.go b/services/wsprd/account/account.go
index 7fa9764..6c6066c 100644
--- a/services/wsprd/account/account.go
+++ b/services/wsprd/account/account.go
@@ -6,11 +6,11 @@
 	"strings"
 	"time"
 
-	"v.io/core/veyron2"
-	"v.io/core/veyron2/context"
-	"v.io/core/veyron2/ipc"
-	"v.io/core/veyron2/security"
-	"v.io/core/veyron2/vlog"
+	"v.io/v23"
+	"v.io/v23/context"
+	"v.io/v23/ipc"
+	"v.io/v23/security"
+	"v.io/v23/vlog"
 	"v.io/wspr/veyron/services/wsprd/principal"
 )
 
@@ -23,7 +23,7 @@
 }
 
 func (s *bs) BlessUsingAccessToken(ctx *context.T, token string, opts ...ipc.CallOpt) (blessingObj security.WireBlessings, account string, err error) {
-	client := veyron2.GetClient(ctx)
+	client := v23.GetClient(ctx)
 	var call ipc.Call
 	if call, err = client.StartCall(ctx, s.name, "BlessUsingAccessToken", []interface{}{token}, opts...); err != nil {
 		return
diff --git a/services/wsprd/account/account.vdl.go b/services/wsprd/account/account.vdl.go
index a0f1211..d76345f 100644
--- a/services/wsprd/account/account.vdl.go
+++ b/services/wsprd/account/account.vdl.go
@@ -5,7 +5,7 @@
 
 import (
 	// VDL system imports
-	"v.io/core/veyron2/vdl"
+	"v.io/v23/vdl"
 )
 
 // Caveat describes a restriction on the validity of a blessing/discharge.
diff --git a/services/wsprd/app/app.go b/services/wsprd/app/app.go
index 7252467..fc15a23 100644
--- a/services/wsprd/app/app.go
+++ b/services/wsprd/app/app.go
@@ -13,18 +13,18 @@
 	"time"
 
 	vsecurity "v.io/core/veyron/security"
-	"v.io/core/veyron2"
-	"v.io/core/veyron2/context"
-	"v.io/core/veyron2/ipc"
-	"v.io/core/veyron2/naming"
-	"v.io/core/veyron2/options"
-	"v.io/core/veyron2/security"
-	"v.io/core/veyron2/vdl"
-	"v.io/core/veyron2/vdl/vdlroot/src/signature"
-	"v.io/core/veyron2/verror"
-	"v.io/core/veyron2/vlog"
-	"v.io/core/veyron2/vom"
-	"v.io/core/veyron2/vtrace"
+	"v.io/v23"
+	"v.io/v23/context"
+	"v.io/v23/ipc"
+	"v.io/v23/naming"
+	"v.io/v23/options"
+	"v.io/v23/security"
+	"v.io/v23/vdl"
+	"v.io/v23/vdl/vdlroot/src/signature"
+	"v.io/v23/verror"
+	"v.io/v23/vlog"
+	"v.io/v23/vom"
+	"v.io/v23/vtrace"
 	"v.io/wspr/veyron/services/wsprd/ipc/server"
 	"v.io/wspr/veyron/services/wsprd/lib"
 	"v.io/wspr/veyron/services/wsprd/namespace"
@@ -118,10 +118,10 @@
 	ctx, _ = vtrace.SetNewTrace(ctx)
 
 	if namespaceRoots != nil {
-		veyron2.GetNamespace(ctx).SetRoots(namespaceRoots...)
+		v23.GetNamespace(ctx).SetRoots(namespaceRoots...)
 	}
 
-	ctx, err := veyron2.SetPrincipal(ctx, p)
+	ctx, err := v23.SetPrincipal(ctx, p)
 	if err != nil {
 		return nil, err
 	}
@@ -214,7 +214,7 @@
 func (c *Controller) startCall(ctx *context.T, w lib.ClientWriter, msg *VeyronRPCRequest, inArgs []interface{}) (ipc.Call, error) {
 	methodName := lib.UppercaseFirstCharacter(msg.Method)
 	retryTimeoutOpt := options.RetryTimeout(time.Duration(*retryTimeout) * time.Second)
-	clientCall, err := veyron2.GetClient(ctx).StartCall(ctx, msg.Name, methodName, inArgs, retryTimeoutOpt)
+	clientCall, err := v23.GetClient(ctx).StartCall(ctx, msg.Name, methodName, inArgs, retryTimeoutOpt)
 	if err != nil {
 		return nil, fmt.Errorf("error starting call (name: %v, method: %v, args: %v): %v", msg.Name, methodName, inArgs, err)
 	}
@@ -686,7 +686,7 @@
 	// out using the Default blessing in this principal's blessings store. We
 	// should change this so that the JS blessing request can also specify the
 	// blessing to be used for the Bless operation.
-	p := veyron2.GetPrincipal(c.ctx)
+	p := v23.GetPrincipal(c.ctx)
 	key := blessee.PublicKey()
 	blessing := p.BlessingStore().Default()
 	blessings, err := p.Bless(key, blessing, extension, caveats[0], caveats[1:]...)
@@ -727,7 +727,7 @@
 	cctx, cancel := context.WithTimeout(ctx.Context(), 5*time.Second)
 	defer cancel()
 
-	call, err := veyron2.GetClient(cctx).StartCall(cctx, name, method, nil)
+	call, err := v23.GetClient(cctx).StartCall(cctx, name, method, nil)
 	if err != nil {
 		return nil, verror.Convert(verror.ErrInternal, cctx, err)
 	}
diff --git a/services/wsprd/app/app.vdl b/services/wsprd/app/app.vdl
index a36178e..7feeead 100644
--- a/services/wsprd/app/app.vdl
+++ b/services/wsprd/app/app.vdl
@@ -3,7 +3,7 @@
 package app
 
 import (
-	"v.io/core/veyron2/vtrace"
+	"v.io/v23/vtrace"
 )
 
 type VeyronRPCRequest struct {
diff --git a/services/wsprd/app/app.vdl.go b/services/wsprd/app/app.vdl.go
index 74545f3..6a5d454 100644
--- a/services/wsprd/app/app.vdl.go
+++ b/services/wsprd/app/app.vdl.go
@@ -7,10 +7,10 @@
 
 import (
 	// VDL system imports
-	"v.io/core/veyron2/vdl"
+	"v.io/v23/vdl"
 
 	// VDL user imports
-	"v.io/core/veyron2/vtrace"
+	"v.io/v23/vtrace"
 )
 
 type VeyronRPCRequest struct {
diff --git a/services/wsprd/app/app_test.go b/services/wsprd/app/app_test.go
index 7fd7106..03cdf46 100644
--- a/services/wsprd/app/app_test.go
+++ b/services/wsprd/app/app_test.go
@@ -7,17 +7,17 @@
 	"reflect"
 	"testing"
 
-	"v.io/core/veyron2"
-	"v.io/core/veyron2/context"
-	"v.io/core/veyron2/ipc"
-	"v.io/core/veyron2/naming"
-	"v.io/core/veyron2/options"
-	"v.io/core/veyron2/security"
-	"v.io/core/veyron2/vdl"
-	"v.io/core/veyron2/vdl/vdlroot/src/signature"
-	"v.io/core/veyron2/verror"
-	"v.io/core/veyron2/vom"
-	"v.io/core/veyron2/vtrace"
+	"v.io/v23"
+	"v.io/v23/context"
+	"v.io/v23/ipc"
+	"v.io/v23/naming"
+	"v.io/v23/options"
+	"v.io/v23/security"
+	"v.io/v23/vdl"
+	"v.io/v23/vdl/vdlroot/src/signature"
+	"v.io/v23/verror"
+	"v.io/v23/vom"
+	"v.io/v23/vtrace"
 	"v.io/wspr/veyron/services/wsprd/ipc/server"
 	"v.io/wspr/veyron/services/wsprd/lib"
 	"v.io/wspr/veyron/services/wsprd/lib/testwriter"
@@ -44,7 +44,7 @@
 		panic(err)
 	}
 
-	principal := veyron2.GetPrincipal(ctx)
+	principal := v23.GetPrincipal(ctx)
 	b, err := principal.Bless(p.PublicKey(), principal.BlessingStore().Default(), "delegate", security.UnconstrainedUse())
 	if err != nil {
 		panic(err)
@@ -116,12 +116,12 @@
 
 func startAnyServer(ctx *context.T, servesMT bool, dispatcher ipc.Dispatcher) (ipc.Server, naming.Endpoint, error) {
 	// Create a new server instance.
-	s, err := veyron2.NewServer(ctx, options.ServesMountTable(servesMT))
+	s, err := v23.NewServer(ctx, options.ServesMountTable(servesMT))
 	if err != nil {
 		return nil, nil, err
 	}
 
-	endpoints, err := s.Listen(veyron2.GetListenSpec(ctx))
+	endpoints, err := s.Listen(v23.GetListenSpec(ctx))
 	if err != nil {
 		return nil, nil, err
 	}
@@ -164,7 +164,7 @@
 	}
 	defer s.Stop()
 
-	spec := veyron2.GetListenSpec(ctx)
+	spec := v23.GetListenSpec(ctx)
 	spec.Proxy = "mockVeyronProxyEP"
 	controller, err := NewController(ctx, nil, &spec, nil, newBlessedPrincipal(ctx))
 
@@ -207,7 +207,7 @@
 	}
 	defer s.Stop()
 
-	spec := veyron2.GetListenSpec(ctx)
+	spec := v23.GetListenSpec(ctx)
 	spec.Proxy = "mockVeyronProxyEP"
 	controller, err := NewController(ctx, nil, &spec, nil, newBlessedPrincipal(ctx))
 
@@ -353,14 +353,14 @@
 	writerCreator := func(int32) lib.ClientWriter {
 		return &writer
 	}
-	spec := veyron2.GetListenSpec(ctx)
+	spec := v23.GetListenSpec(ctx)
 	spec.Proxy = "/" + proxyEndpoint
 	controller, err := NewController(ctx, writerCreator, &spec, nil, testPrincipal)
 	if err != nil {
 		return nil, err
 	}
 
-	veyron2.GetNamespace(controller.Context()).SetRoots("/" + endpoint.String())
+	v23.GetNamespace(controller.Context()).SetRoots("/" + endpoint.String())
 
 	req, err := makeRequest(VeyronRPCRequest{
 		Name:       "__controller",
@@ -511,7 +511,7 @@
 
 	// Get the client that is relevant to the controller so it talks
 	// to the right mounttable.
-	client := veyron2.GetClient(rt.controller.Context())
+	client := v23.GetClient(rt.controller.Context())
 
 	if err != nil {
 		t.Errorf("unable to create client: %v", err)
diff --git a/services/wsprd/app/controller.vdl b/services/wsprd/app/controller.vdl
index 7c34069..9804123 100644
--- a/services/wsprd/app/controller.vdl
+++ b/services/wsprd/app/controller.vdl
@@ -4,7 +4,7 @@
 	"signature"
 	"time"
 
-	"v.io/core/veyron2/security"
+	"v.io/v23/security"
 )
 
 type Controller interface {
diff --git a/services/wsprd/app/controller.vdl.go b/services/wsprd/app/controller.vdl.go
index f41d339..0937604 100644
--- a/services/wsprd/app/controller.vdl.go
+++ b/services/wsprd/app/controller.vdl.go
@@ -5,15 +5,15 @@
 
 import (
 	// VDL system imports
-	"v.io/core/veyron2"
-	"v.io/core/veyron2/context"
-	"v.io/core/veyron2/ipc"
+	"v.io/v23"
+	"v.io/v23/context"
+	"v.io/v23/ipc"
 
 	// VDL user imports
 	"time"
-	"v.io/core/veyron2/security"
-	"v.io/core/veyron2/vdl/vdlroot/src/signature"
-	_ "v.io/core/veyron2/vdl/vdlroot/src/time"
+	"v.io/v23/security"
+	"v.io/v23/vdl/vdlroot/src/signature"
+	_ "v.io/v23/vdl/vdlroot/src/time"
 )
 
 // ControllerClientMethods is the client interface
@@ -67,7 +67,7 @@
 	if c.client != nil {
 		return c.client
 	}
-	return veyron2.GetClient(ctx)
+	return v23.GetClient(ctx)
 }
 
 func (c implControllerClientStub) Serve(ctx *context.T, i0 string, i1 uint32, opts ...ipc.CallOpt) (err error) {
diff --git a/services/wsprd/app/messaging.go b/services/wsprd/app/messaging.go
index 7865870..911fe22 100644
--- a/services/wsprd/app/messaging.go
+++ b/services/wsprd/app/messaging.go
@@ -6,10 +6,10 @@
 	"path/filepath"
 	"runtime"
 
-	"v.io/core/veyron2/verror"
-	"v.io/core/veyron2/vlog"
-	"v.io/core/veyron2/vom"
-	"v.io/core/veyron2/vtrace"
+	"v.io/v23/verror"
+	"v.io/v23/vlog"
+	"v.io/v23/vom"
+	"v.io/v23/vtrace"
 	"v.io/wspr/veyron/services/wsprd/lib"
 )
 
diff --git a/services/wsprd/app/mock_jsServer_test.go b/services/wsprd/app/mock_jsServer_test.go
index 56f1c82..f3f848f 100644
--- a/services/wsprd/app/mock_jsServer_test.go
+++ b/services/wsprd/app/mock_jsServer_test.go
@@ -8,8 +8,8 @@
 	"sync"
 	"testing"
 
-	"v.io/core/veyron2/vdl"
-	"v.io/core/veyron2/vdl/vdlroot/src/signature"
+	"v.io/v23/vdl"
+	"v.io/v23/vdl/vdlroot/src/signature"
 	"v.io/wspr/veyron/services/wsprd/ipc/server"
 	"v.io/wspr/veyron/services/wsprd/lib"
 	"v.io/wspr/veyron/services/wsprd/principal"
@@ -58,7 +58,7 @@
 func internalErrJSON(args interface{}) string {
 	return fmt.Sprintf(`{"err": {
 			"idAction": {
-				"id": "v.io/core/veyron2/verror.Internal",
+				"id": "v.io/v23/verror.Internal",
 				"action": 0
 			},
 			"paramList": ["%v"]}, "results":[null]}`, args)
diff --git a/services/wsprd/app/stream.go b/services/wsprd/app/stream.go
index b576453..9cb1764 100644
--- a/services/wsprd/app/stream.go
+++ b/services/wsprd/app/stream.go
@@ -3,7 +3,7 @@
 import (
 	"fmt"
 
-	"v.io/core/veyron2/ipc"
+	"v.io/v23/ipc"
 	"v.io/wspr/veyron/services/wsprd/lib"
 )
 
diff --git a/services/wsprd/browspr/browspr.go b/services/wsprd/browspr/browspr.go
index 1c5f6b5..8da654a 100644
--- a/services/wsprd/browspr/browspr.go
+++ b/services/wsprd/browspr/browspr.go
@@ -6,12 +6,12 @@
 	"reflect"
 	"sync"
 
-	"v.io/core/veyron2"
-	"v.io/core/veyron2/context"
-	"v.io/core/veyron2/ipc"
-	"v.io/core/veyron2/vdl"
-	"v.io/core/veyron2/vlog"
-	"v.io/core/veyron2/vtrace"
+	"v.io/v23"
+	"v.io/v23/context"
+	"v.io/v23/ipc"
+	"v.io/v23/vdl"
+	"v.io/v23/vlog"
+	"v.io/v23/vtrace"
 	"v.io/wspr/veyron/services/wsprd/account"
 	"v.io/wspr/veyron/services/wsprd/principal"
 )
@@ -54,7 +54,7 @@
 
 	// TODO(nlacasse, bjornick) use a serializer that can actually persist.
 	var err error
-	p := veyron2.GetPrincipal(ctx)
+	p := v23.GetPrincipal(ctx)
 	if browspr.principalManager, err = principal.NewPrincipalManager(p, &principal.InMemorySerializer{}); err != nil {
 		vlog.Fatalf("principal.NewPrincipalManager failed: %s", err)
 	}
diff --git a/services/wsprd/browspr/browspr.vdl.go b/services/wsprd/browspr/browspr.vdl.go
index ac1d6e1..179c1c7 100644
--- a/services/wsprd/browspr/browspr.vdl.go
+++ b/services/wsprd/browspr/browspr.vdl.go
@@ -5,7 +5,7 @@
 
 import (
 	// VDL system imports
-	"v.io/core/veyron2/vdl"
+	"v.io/v23/vdl"
 
 	// VDL user imports
 	"v.io/wspr/veyron/services/wsprd/account"
diff --git a/services/wsprd/browspr/browspr_account_test.go b/services/wsprd/browspr/browspr_account_test.go
index 119c91c..9eb94f7 100644
--- a/services/wsprd/browspr/browspr_account_test.go
+++ b/services/wsprd/browspr/browspr_account_test.go
@@ -4,11 +4,11 @@
 	"fmt"
 	"testing"
 
-	"v.io/core/veyron2"
-	"v.io/core/veyron2/context"
-	"v.io/core/veyron2/ipc"
-	"v.io/core/veyron2/security"
-	"v.io/core/veyron2/vdl"
+	"v.io/v23"
+	"v.io/v23/context"
+	"v.io/v23/ipc"
+	"v.io/v23/security"
+	"v.io/v23/vdl"
 
 	"v.io/core/veyron/lib/testutil"
 	_ "v.io/core/veyron/profiles"
@@ -42,11 +42,11 @@
 func setup(t *testing.T) (*Browspr, func()) {
 	ctx, shutdown := testutil.InitForTest()
 
-	spec := veyron2.GetListenSpec(ctx)
+	spec := v23.GetListenSpec(ctx)
 	spec.Proxy = "/mock/proxy"
 	mockPostMessage := func(_ int32, _, _ string) {}
 	browspr := NewBrowspr(ctx, mockPostMessage, &spec, "/mock:1234/identd", nil)
-	principal := veyron2.GetPrincipal(browspr.ctx)
+	principal := v23.GetPrincipal(browspr.ctx)
 	browspr.accountManager.SetMockBlesser(newMockBlesserService(principal))
 
 	return browspr, func() {
@@ -125,7 +125,7 @@
 
 	// First create an account.
 	account := "mock-account"
-	principal := veyron2.GetPrincipal(browspr.ctx)
+	principal := v23.GetPrincipal(browspr.ctx)
 	blessing, err := principal.BlessSelf(account)
 	if err != nil {
 		t.Fatalf("browspr.rt.Principal.BlessSelf(%v) failed: %v", account, err)
diff --git a/services/wsprd/browspr/browspr_test.go b/services/wsprd/browspr/browspr_test.go
index 36279eb..c5fcd98 100644
--- a/services/wsprd/browspr/browspr_test.go
+++ b/services/wsprd/browspr/browspr_test.go
@@ -8,13 +8,13 @@
 	"testing"
 	"time"
 
-	"v.io/core/veyron2"
-	"v.io/core/veyron2/context"
-	"v.io/core/veyron2/ipc"
-	"v.io/core/veyron2/naming"
-	"v.io/core/veyron2/options"
-	"v.io/core/veyron2/vdl"
-	"v.io/core/veyron2/vom"
+	"v.io/v23"
+	"v.io/v23/context"
+	"v.io/v23/ipc"
+	"v.io/v23/naming"
+	"v.io/v23/options"
+	"v.io/v23/vdl"
+	"v.io/v23/vom"
 
 	"v.io/core/veyron/lib/testutil"
 	_ "v.io/core/veyron/profiles"
@@ -38,12 +38,12 @@
 		return nil, nil, err
 	}
 
-	s, err := veyron2.NewServer(ctx, options.ServesMountTable(true))
+	s, err := v23.NewServer(ctx, options.ServesMountTable(true))
 	if err != nil {
 		return nil, nil, err
 	}
 
-	endpoints, err := s.Listen(veyron2.GetListenSpec(ctx))
+	endpoints, err := s.Listen(v23.GetListenSpec(ctx))
 	if err != nil {
 		return nil, nil, err
 	}
@@ -63,12 +63,12 @@
 
 func startMockServer(ctx *context.T, desiredName string) (ipc.Server, naming.Endpoint, error) {
 	// Create a new server instance.
-	s, err := veyron2.NewServer(ctx)
+	s, err := v23.NewServer(ctx)
 	if err != nil {
 		return nil, nil, err
 	}
 
-	endpoints, err := s.Listen(veyron2.GetListenSpec(ctx))
+	endpoints, err := s.Listen(v23.GetListenSpec(ctx))
 	if err != nil {
 		return nil, nil, err
 	}
@@ -96,7 +96,7 @@
 	}
 	defer mtServer.Stop()
 	root := mtEndpoint.Name()
-	if err := veyron2.GetNamespace(ctx).SetRoots(root); err != nil {
+	if err := v23.GetNamespace(ctx).SetRoots(root); err != nil {
 		t.Fatalf("Failed to set namespace roots: %v", err)
 	}
 
@@ -124,7 +124,7 @@
 		}
 		time.Sleep(100 * time.Millisecond)
 	}
-	mountEntry, err := veyron2.GetNamespace(ctx).Resolve(ctx, mockServerName)
+	mountEntry, err := v23.GetNamespace(ctx).Resolve(ctx, mockServerName)
 	if err != nil {
 		t.Fatalf("Error fetching published names from mounttable: %v", err)
 	}
@@ -139,7 +139,7 @@
 		t.Fatalf("Incorrect names retrieved from mounttable: %v", mountEntry)
 	}
 
-	spec := veyron2.GetListenSpec(ctx)
+	spec := v23.GetListenSpec(ctx)
 	spec.Proxy = proxy.Endpoint().String()
 
 	receivedResponse := make(chan bool, 1)
@@ -154,13 +154,13 @@
 		receivedResponse <- true
 	}
 
-	veyron2.GetNamespace(ctx).SetRoots(root)
+	v23.GetNamespace(ctx).SetRoots(root)
 	browspr := NewBrowspr(ctx, postMessageHandler, &spec, "/mock:1234/identd", []string{root})
 
 	// browspr sets its namespace root to use the "ws" protocol, but we want to force "tcp" here.
 	browspr.namespaceRoots = []string{root}
 
-	browspr.accountManager.SetMockBlesser(newMockBlesserService(veyron2.GetPrincipal(ctx)))
+	browspr.accountManager.SetMockBlesser(newMockBlesserService(v23.GetPrincipal(ctx)))
 
 	msgInstanceId := int32(11)
 	msgOrigin := "http://test-origin.com"
@@ -168,7 +168,7 @@
 	// Associate the origin with the root accounts' blessings, otherwise a
 	// dummy account will be used and will be rejected by the authorizer.
 	accountName := "test-account"
-	bp := veyron2.GetPrincipal(browspr.ctx)
+	bp := v23.GetPrincipal(browspr.ctx)
 	if err := browspr.principalManager.AddAccount(accountName, bp.BlessingStore().Default()); err != nil {
 		t.Fatalf("Failed to add account: %v")
 	}
diff --git a/services/wsprd/browspr/main/main_nacl.go b/services/wsprd/browspr/main/main_nacl.go
index 7d50e19..4a321e6 100644
--- a/services/wsprd/browspr/main/main_nacl.go
+++ b/services/wsprd/browspr/main/main_nacl.go
@@ -11,10 +11,10 @@
 	"v.io/core/veyron/lib/websocket"
 	_ "v.io/core/veyron/profiles/chrome"
 	vsecurity "v.io/core/veyron/security"
-	"v.io/core/veyron2"
-	"v.io/core/veyron2/security"
-	"v.io/core/veyron2/vdl"
-	"v.io/core/veyron2/vlog"
+	"v.io/v23"
+	"v.io/v23/security"
+	"v.io/v23/vdl"
+	"v.io/v23/vlog"
 	"v.io/wspr/veyron/services/wsprd/browspr"
 	"v.io/wspr/veyron/services/wsprd/channel/channel_nacl"
 )
@@ -194,9 +194,9 @@
 
 	// Initialize the runtime.
 	// TODO(suharshs,mattr): Should we worried about not shutting down here?
-	ctx, _ := veyron2.Init()
+	ctx, _ := v23.Init()
 
-	ctx, err = veyron2.SetPrincipal(ctx, principal)
+	ctx, err = v23.SetPrincipal(ctx, principal)
 	if err != nil {
 		return nil, err
 	}
@@ -210,9 +210,9 @@
 	// TODO(ataly, bprosnitz, caprita): The runtime MUST be cleaned up
 	// after use. Figure out the appropriate place to add the Cleanup call.
 
-	veyron2.GetNamespace(ctx).SetRoots(msg.NamespaceRoot)
+	v23.GetNamespace(ctx).SetRoots(msg.NamespaceRoot)
 
-	listenSpec := veyron2.GetListenSpec(ctx)
+	listenSpec := v23.GetListenSpec(ctx)
 	listenSpec.Proxy = msg.Proxy
 
 	vlog.VI(1).Infof("Starting browspr with config: proxy=%q mounttable=%q identityd=%q identitydBlessingRoot=%q ", msg.Proxy, msg.NamespaceRoot, msg.Identityd, msg.IdentitydBlessingRoot)
diff --git a/services/wsprd/browspr/pipe.go b/services/wsprd/browspr/pipe.go
index dedc606..b88e401 100644
--- a/services/wsprd/browspr/pipe.go
+++ b/services/wsprd/browspr/pipe.go
@@ -4,7 +4,7 @@
 	"encoding/json"
 	"fmt"
 
-	"v.io/core/veyron2/vlog"
+	"v.io/v23/vlog"
 	"v.io/wspr/veyron/services/wsprd/app"
 	"v.io/wspr/veyron/services/wsprd/lib"
 )
diff --git a/services/wsprd/channel/channel.go b/services/wsprd/channel/channel.go
index ec1071b..d5e1aed 100644
--- a/services/wsprd/channel/channel.go
+++ b/services/wsprd/channel/channel.go
@@ -4,7 +4,7 @@
 	"fmt"
 	"sync"
 
-	"v.io/core/veyron2/vdl"
+	"v.io/v23/vdl"
 )
 
 type RequestHandler func(*vdl.Value) (*vdl.Value, error)
diff --git a/services/wsprd/channel/channel.vdl.go b/services/wsprd/channel/channel.vdl.go
index 9e328fe..1025bdc 100644
--- a/services/wsprd/channel/channel.vdl.go
+++ b/services/wsprd/channel/channel.vdl.go
@@ -5,7 +5,7 @@
 
 import (
 	// VDL system imports
-	"v.io/core/veyron2/vdl"
+	"v.io/v23/vdl"
 )
 
 type Request struct {
diff --git a/services/wsprd/channel/channel_nacl/channel_nacl.go b/services/wsprd/channel/channel_nacl/channel_nacl.go
index 6b20261..cab05ba 100644
--- a/services/wsprd/channel/channel_nacl/channel_nacl.go
+++ b/services/wsprd/channel/channel_nacl/channel_nacl.go
@@ -5,8 +5,8 @@
 	"fmt"
 	"runtime/ppapi"
 
-	"v.io/core/veyron2/vdl"
-	"v.io/core/veyron2/vom"
+	"v.io/v23/vdl"
+	"v.io/v23/vom"
 	"v.io/wspr/veyron/services/wsprd/channel" // contains most of the logic, factored out for testing
 )
 
diff --git a/services/wsprd/channel/channel_test.go b/services/wsprd/channel/channel_test.go
index 9b1de1d..86f4ac9 100644
--- a/services/wsprd/channel/channel_test.go
+++ b/services/wsprd/channel/channel_test.go
@@ -5,7 +5,7 @@
 	"sync"
 	"testing"
 
-	"v.io/core/veyron2/vdl"
+	"v.io/v23/vdl"
 	"v.io/wspr/veyron/services/wsprd/channel"
 )
 
diff --git a/services/wsprd/ipc/server/authorizer.go b/services/wsprd/ipc/server/authorizer.go
index e9e0e77..47f9436 100644
--- a/services/wsprd/ipc/server/authorizer.go
+++ b/services/wsprd/ipc/server/authorizer.go
@@ -1,7 +1,7 @@
 package server
 
 import (
-	"v.io/core/veyron2/security"
+	"v.io/v23/security"
 )
 
 type authorizer struct {
diff --git a/services/wsprd/ipc/server/dispatcher.go b/services/wsprd/ipc/server/dispatcher.go
index 99f7185..f312c35 100644
--- a/services/wsprd/ipc/server/dispatcher.go
+++ b/services/wsprd/ipc/server/dispatcher.go
@@ -8,11 +8,11 @@
 
 	"v.io/wspr/veyron/services/wsprd/lib"
 
-	"v.io/core/veyron2/ipc"
-	"v.io/core/veyron2/security"
-	"v.io/core/veyron2/vdl/vdlroot/src/signature"
-	"v.io/core/veyron2/verror"
-	"v.io/core/veyron2/vlog"
+	"v.io/v23/ipc"
+	"v.io/v23/security"
+	"v.io/v23/vdl/vdlroot/src/signature"
+	"v.io/v23/verror"
+	"v.io/v23/vlog"
 )
 
 type flowFactory interface {
diff --git a/services/wsprd/ipc/server/dispatcher_test.go b/services/wsprd/ipc/server/dispatcher_test.go
index 602e15c..ee923c3 100644
--- a/services/wsprd/ipc/server/dispatcher_test.go
+++ b/services/wsprd/ipc/server/dispatcher_test.go
@@ -5,10 +5,10 @@
 	"reflect"
 	"testing"
 
-	"v.io/core/veyron2/ipc"
-	"v.io/core/veyron2/security"
-	"v.io/core/veyron2/vdl"
-	"v.io/core/veyron2/vdl/vdlroot/src/signature"
+	"v.io/v23/ipc"
+	"v.io/v23/security"
+	"v.io/v23/vdl"
+	"v.io/v23/vdl/vdlroot/src/signature"
 	"v.io/wspr/veyron/services/wsprd/lib"
 	"v.io/wspr/veyron/services/wsprd/lib/testwriter"
 )
diff --git a/services/wsprd/ipc/server/invoker.go b/services/wsprd/ipc/server/invoker.go
index f2f9877..b31ce34 100644
--- a/services/wsprd/ipc/server/invoker.go
+++ b/services/wsprd/ipc/server/invoker.go
@@ -1,12 +1,12 @@
 package server
 
 import (
-	"v.io/core/veyron2/context"
-	"v.io/core/veyron2/ipc"
-	"v.io/core/veyron2/naming"
-	"v.io/core/veyron2/vdl"
-	"v.io/core/veyron2/vdl/vdlroot/src/signature"
-	"v.io/core/veyron2/verror"
+	"v.io/v23/context"
+	"v.io/v23/ipc"
+	"v.io/v23/naming"
+	"v.io/v23/vdl"
+	"v.io/v23/vdl/vdlroot/src/signature"
+	"v.io/v23/verror"
 )
 
 var typedNil []int
diff --git a/services/wsprd/ipc/server/server.go b/services/wsprd/ipc/server/server.go
index 50e5a74..0248268 100644
--- a/services/wsprd/ipc/server/server.go
+++ b/services/wsprd/ipc/server/server.go
@@ -11,15 +11,15 @@
 	"v.io/wspr/veyron/services/wsprd/lib"
 	"v.io/wspr/veyron/services/wsprd/principal"
 
-	"v.io/core/veyron2"
-	"v.io/core/veyron2/context"
-	"v.io/core/veyron2/ipc"
-	"v.io/core/veyron2/naming"
-	"v.io/core/veyron2/security"
-	"v.io/core/veyron2/vdl"
-	"v.io/core/veyron2/vdl/vdlroot/src/signature"
-	"v.io/core/veyron2/verror"
-	"v.io/core/veyron2/vlog"
+	"v.io/v23"
+	"v.io/v23/context"
+	"v.io/v23/ipc"
+	"v.io/v23/naming"
+	"v.io/v23/security"
+	"v.io/v23/vdl"
+	"v.io/v23/vdl/vdlroot/src/signature"
+	"v.io/v23/verror"
+	"v.io/v23/vlog"
 )
 
 type Flow struct {
@@ -120,7 +120,7 @@
 		outstandingAuthRequests:   make(map[int32]chan error),
 	}
 	var err error
-	if server.server, err = veyron2.NewServer(helper.Context()); err != nil {
+	if server.server, err = v23.NewServer(helper.Context()); err != nil {
 		return nil, err
 	}
 	return server, nil
diff --git a/services/wsprd/lib/signature_manager.go b/services/wsprd/lib/signature_manager.go
index 76177a3..3ac9927 100644
--- a/services/wsprd/lib/signature_manager.go
+++ b/services/wsprd/lib/signature_manager.go
@@ -4,11 +4,11 @@
 	"sync"
 	"time"
 
-	"v.io/core/veyron2/context"
-	"v.io/core/veyron2/ipc"
-	"v.io/core/veyron2/ipc/reserved"
-	"v.io/core/veyron2/vdl/vdlroot/src/signature"
-	"v.io/core/veyron2/verror"
+	"v.io/v23/context"
+	"v.io/v23/ipc"
+	"v.io/v23/ipc/reserved"
+	"v.io/v23/vdl/vdlroot/src/signature"
+	"v.io/v23/verror"
 )
 
 type SignatureManager interface {
diff --git a/services/wsprd/lib/signature_manager_test.go b/services/wsprd/lib/signature_manager_test.go
index 5f35f9e..f121662 100644
--- a/services/wsprd/lib/signature_manager_test.go
+++ b/services/wsprd/lib/signature_manager_test.go
@@ -9,17 +9,17 @@
 	_ "v.io/core/veyron/profiles/fake"
 	"v.io/core/veyron/runtimes/fake"
 	mocks_ipc "v.io/core/veyron/runtimes/google/testing/mocks/ipc"
-	"v.io/core/veyron2"
-	"v.io/core/veyron2/context"
-	"v.io/core/veyron2/vdl"
-	"v.io/core/veyron2/vdl/vdlroot/src/signature"
+	"v.io/v23"
+	"v.io/v23/context"
+	"v.io/v23/vdl"
+	"v.io/v23/vdl/vdlroot/src/signature"
 )
 
 const (
 	name = "/veyron/name"
 )
 
-func initContext(t *testing.T) (*context.T, mocks_ipc.ClientWithTimesCalled, veyron2.Shutdown) {
+func initContext(t *testing.T) (*context.T, mocks_ipc.ClientWithTimesCalled, v23.Shutdown) {
 	ctx, shutdown := testutil.InitForTest()
 	initialSig := []signature.Interface{
 		{
diff --git a/services/wsprd/lib/testwriter/writer.go b/services/wsprd/lib/testwriter/writer.go
index 42e7c99..48dda10 100644
--- a/services/wsprd/lib/testwriter/writer.go
+++ b/services/wsprd/lib/testwriter/writer.go
@@ -8,7 +8,7 @@
 	"sync"
 	"time"
 
-	"v.io/core/veyron2/verror"
+	"v.io/v23/verror"
 	"v.io/wspr/veyron/services/wsprd/lib"
 )
 
diff --git a/services/wsprd/lib/time.go b/services/wsprd/lib/time.go
index 97da91e..7b417cf 100644
--- a/services/wsprd/lib/time.go
+++ b/services/wsprd/lib/time.go
@@ -3,7 +3,7 @@
 import (
 	"time"
 
-	"v.io/core/veyron2/ipc"
+	"v.io/v23/ipc"
 )
 
 const nanosecondsPerMillisecond = 1000000
diff --git a/services/wsprd/lib/vom.go b/services/wsprd/lib/vom.go
index dd40103..431644d 100644
--- a/services/wsprd/lib/vom.go
+++ b/services/wsprd/lib/vom.go
@@ -4,7 +4,7 @@
 	"bytes"
 	"encoding/hex"
 
-	"v.io/core/veyron2/vom"
+	"v.io/v23/vom"
 )
 
 func VomEncode(v interface{}) (string, error) {
diff --git a/services/wsprd/lib/writer.vdl.go b/services/wsprd/lib/writer.vdl.go
index 78cf271..93c230b 100644
--- a/services/wsprd/lib/writer.vdl.go
+++ b/services/wsprd/lib/writer.vdl.go
@@ -5,7 +5,7 @@
 
 import (
 	// VDL system imports
-	"v.io/core/veyron2/vdl"
+	"v.io/v23/vdl"
 )
 
 // The response from the javascript server to the proxy.
diff --git a/services/wsprd/namespace/namespace.vdl b/services/wsprd/namespace/namespace.vdl
index d8ce654..85bfcea 100644
--- a/services/wsprd/namespace/namespace.vdl
+++ b/services/wsprd/namespace/namespace.vdl
@@ -1,13 +1,13 @@
 // Package namespace defines an RPC services that allows remoting of the
 // namespace client library over the wire.  This is useful for
 // javascript so it doesn't have to implement the library.
-// This should be kept in sync with the namespace library (v.io/core/veyron2/naming).
+// This should be kept in sync with the namespace library (v.io/v23/naming).
 package namespace
 
 import (
 	"time"
 
-	"v.io/core/veyron2/naming"
+	"v.io/v23/naming"
 )
 
 type Namespace interface {
diff --git a/services/wsprd/namespace/request_handler.go b/services/wsprd/namespace/request_handler.go
index fcf2cc5..2c26fb7 100644
--- a/services/wsprd/namespace/request_handler.go
+++ b/services/wsprd/namespace/request_handler.go
@@ -3,11 +3,11 @@
 import (
 	"time"
 
-	"v.io/core/veyron2"
-	"v.io/core/veyron2/context"
-	"v.io/core/veyron2/ipc"
-	"v.io/core/veyron2/naming"
-	"v.io/core/veyron2/verror"
+	"v.io/v23"
+	"v.io/v23/context"
+	"v.io/v23/ipc"
+	"v.io/v23/naming"
+	"v.io/v23/verror"
 )
 
 type Server struct {
@@ -15,7 +15,7 @@
 }
 
 func New(ctx *context.T) *Server {
-	return &Server{veyron2.GetNamespace(ctx)}
+	return &Server{v23.GetNamespace(ctx)}
 }
 
 func (s *Server) Glob(ctx *NamespaceGlobContextStub, pattern string) error {
diff --git a/services/wsprd/principal/blessings.go b/services/wsprd/principal/blessings.go
index cdcad83..ef6a281 100644
--- a/services/wsprd/principal/blessings.go
+++ b/services/wsprd/principal/blessings.go
@@ -2,7 +2,7 @@
 
 import (
 	"encoding/base64"
-	"v.io/core/veyron2/security"
+	"v.io/v23/security"
 )
 
 type BlessingsHandle struct {
diff --git a/services/wsprd/principal/js_blessings_store.go b/services/wsprd/principal/js_blessings_store.go
index d427e7f..5537a89 100644
--- a/services/wsprd/principal/js_blessings_store.go
+++ b/services/wsprd/principal/js_blessings_store.go
@@ -3,7 +3,7 @@
 import (
 	"sync"
 
-	"v.io/core/veyron2/security"
+	"v.io/v23/security"
 )
 
 // JSBlessingsHandles is a store for Blessings in use by JS code.
diff --git a/services/wsprd/principal/principal.go b/services/wsprd/principal/principal.go
index 6fc336c..29a8be8 100644
--- a/services/wsprd/principal/principal.go
+++ b/services/wsprd/principal/principal.go
@@ -37,9 +37,9 @@
 	vsecurity "v.io/core/veyron/security"
 	"v.io/core/veyron/security/serialization"
 
-	"v.io/core/veyron2/security"
-	"v.io/core/veyron2/verror"
-	"v.io/core/veyron2/vom"
+	"v.io/v23/security"
+	"v.io/v23/verror"
+	"v.io/v23/vom"
 )
 
 // permissions is a set of a permissions given to an app, containing the account
diff --git a/services/wsprd/principal/principal_test.go b/services/wsprd/principal/principal_test.go
index 081af72..a59d9c8 100644
--- a/services/wsprd/principal/principal_test.go
+++ b/services/wsprd/principal/principal_test.go
@@ -8,9 +8,9 @@
 	"testing"
 	"time"
 
-	"v.io/core/veyron2/security"
-	"v.io/core/veyron2/verror"
-	"v.io/core/veyron2/vom"
+	"v.io/v23/security"
+	"v.io/v23/verror"
+	"v.io/v23/vom"
 )
 
 func accountBlessing(p security.Principal, name string) security.Blessings {
diff --git a/services/wsprd/principal/util_test.go b/services/wsprd/principal/util_test.go
index c8d420b..7708ec2 100644
--- a/services/wsprd/principal/util_test.go
+++ b/services/wsprd/principal/util_test.go
@@ -6,8 +6,8 @@
 
 	vsecurity "v.io/core/veyron/security"
 
-	"v.io/core/veyron2/security"
-	"v.io/core/veyron2/verror"
+	"v.io/v23/security"
+	"v.io/v23/verror"
 )
 
 func newPrincipal() security.Principal {
diff --git a/services/wsprd/wspr.go b/services/wsprd/wspr.go
index 2945ead..b9bef4b 100644
--- a/services/wsprd/wspr.go
+++ b/services/wsprd/wspr.go
@@ -5,7 +5,7 @@
 	"fmt"
 	"net"
 
-	"v.io/core/veyron2"
+	"v.io/v23"
 
 	"v.io/core/veyron/lib/signals"
 	// TODO(cnicolaou,benj): figure out how to support roaming as a chrome plugin
@@ -19,10 +19,10 @@
 
 	flag.Parse()
 
-	ctx, shutdown := veyron2.Init()
+	ctx, shutdown := v23.Init()
 	defer shutdown()
 
-	listenSpec := veyron2.GetListenSpec(ctx)
+	listenSpec := v23.GetListenSpec(ctx)
 	proxy := wspr.NewWSPR(ctx, *port, &listenSpec, *identd, nil)
 	defer proxy.Shutdown()
 
diff --git a/services/wsprd/wspr/pipe.go b/services/wsprd/wspr/pipe.go
index 4af7aaa..d32436c 100644
--- a/services/wsprd/wspr/pipe.go
+++ b/services/wsprd/wspr/pipe.go
@@ -8,8 +8,8 @@
 	_ "net/http/pprof"
 	"time"
 
-	"v.io/core/veyron2"
-	"v.io/core/veyron2/vlog"
+	"v.io/v23"
+	"v.io/v23/vlog"
 	"v.io/wspr/veyron/services/wsprd/app"
 	"v.io/wspr/veyron/services/wsprd/lib"
 
@@ -61,7 +61,7 @@
 
 	p, err := wspr.principalManager.Principal(origin)
 	if err != nil {
-		p = veyron2.GetPrincipal(wspr.ctx)
+		p = v23.GetPrincipal(wspr.ctx)
 		vlog.Errorf("no principal associated with origin %s: %v", origin, err)
 		// TODO(bjornick): Send an error to the client when all of the principal stuff is set up.
 	}
diff --git a/services/wsprd/wspr/writer.go b/services/wsprd/wspr/writer.go
index 8b538ad..930e4a6 100644
--- a/services/wsprd/wspr/writer.go
+++ b/services/wsprd/wspr/writer.go
@@ -7,8 +7,8 @@
 
 	"v.io/wspr/veyron/services/wsprd/lib"
 
-	"v.io/core/veyron2/verror"
-	"v.io/core/veyron2/vlog"
+	"v.io/v23/verror"
+	"v.io/v23/vlog"
 	"v.io/wspr/veyron/services/wsprd/app"
 
 	"github.com/gorilla/websocket"
diff --git a/services/wsprd/wspr/wspr.go b/services/wsprd/wspr/wspr.go
index a9dada3..c1db32f 100644
--- a/services/wsprd/wspr/wspr.go
+++ b/services/wsprd/wspr/wspr.go
@@ -25,10 +25,10 @@
 	"sync"
 	"time"
 
-	"v.io/core/veyron2"
-	"v.io/core/veyron2/context"
-	"v.io/core/veyron2/ipc"
-	"v.io/core/veyron2/vlog"
+	"v.io/v23"
+	"v.io/v23/context"
+	"v.io/v23/ipc"
+	"v.io/v23/vlog"
 
 	"v.io/wspr/veyron/services/wsprd/account"
 	"v.io/wspr/veyron/services/wsprd/principal"
@@ -134,7 +134,7 @@
 	}
 
 	// TODO(nlacasse, bjornick) use a serializer that can actually persist.
-	p := veyron2.GetPrincipal(ctx)
+	p := v23.GetPrincipal(ctx)
 	var err error
 	if wspr.principalManager, err = principal.NewPrincipalManager(p, &principal.InMemorySerializer{}); err != nil {
 		vlog.Fatalf("principal.NewPrincipalManager failed: %s", err)
diff --git a/services/wsprd/namespace/namespace.vdl.go b/services/wsprd/namespace/namespace.vdl.go
index 4cbe8c9..faf0e3b 100644
--- a/services/wsprd/namespace/namespace.vdl.go
+++ b/services/wsprd/namespace/namespace.vdl.go
@@ -4,20 +4,20 @@
 // Package namespace defines an RPC services that allows remoting of the
 // namespace client library over the wire.  This is useful for
 // javascript so it doesn't have to implement the library.
 // This should be kept in sync with the namespace library (v.io/core/veyron2/naming).
 package namespace
 
 import (
 	// VDL system imports
 	"io"
-	"v.io/core/veyron2"
-	"v.io/core/veyron2/context"
-	"v.io/core/veyron2/ipc"
+	"v.io/v23"
+	"v.io/v23/context"
+	"v.io/v23/ipc"
 
 	// VDL user imports
 	"time"
-	"v.io/core/veyron2/naming"
-	_ "v.io/core/veyron2/vdl/vdlroot/src/time"
+	"v.io/v23/naming"
+	_ "v.io/v23/vdl/vdlroot/src/time"
 )
 
 // NamespaceClientMethods is the client interface
@@ -70,7 +70,7 @@
 	if c.client != nil {
 		return c.client
 	}
-	return veyron2.GetClient(ctx)
+	return v23.GetClient(ctx)
 }
 
 func (c implNamespaceClientStub) Glob(ctx *context.T, i0 string, opts ...ipc.CallOpt) (ocall NamespaceGlobCall, err error) {
@@ -4,20 +4,20 @@
 // namespace client library over the wire.  This is useful for
 // javascript so it doesn't have to implement the library.
-// This should be kept in sync with the namespace library (v.io/core/veyron2/naming).
+// This should be kept in sync with the namespace library (v.io/v23/naming).
 package namespace
 